{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "samtools view cram to bam",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-b"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/output.bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#cram_to_bam.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#cram_to_bam.cwl/reference"
                }
            ],
            "id": "#cram_to_bam.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.bam"
                    },
                    "id": "#cram_to_bam.cwl/bam"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "cram_to_bam workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl/cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#workflow.cwl/bam"
                }
            ],
            "steps": [
                {
                    "run": "#cram_to_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram",
                            "id": "#workflow.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow.cwl/reference",
                            "id": "#workflow.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/cram_to_bam/bam"
                    ],
                    "id": "#workflow.cwl/cram_to_bam"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram_to_bam/bam",
                            "id": "#workflow.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#workflow.cwl/index_bam"
                }
            ],
            "id": "#workflow.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add VEP annotation to report",
            "baseCommand": [
                "/usr/bin/python",
                "/usr/bin/add_annotations_to_table_helper.py"
            ],
            "arguments": [
                {
                    "position": 4,
                    "valueFrom": "$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#add_vep_fields_to_table.cwl/tsv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#add_vep_fields_to_table.cwl/vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "prefix": "",
                        "itemSeparator": ",",
                        "separate": false,
                        "position": 3
                    },
                    "id": "#add_vep_fields_to_table.cwl/vep_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "variants.annotated.tsv"
                    },
                    "id": "#add_vep_fields_to_table.cwl/annotated_variants_tsv"
                }
            ],
            "id": "#add_vep_fields_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "CombineVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "CombineVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-genotypeMergeOptions",
                "PRIORITIZE",
                "--rod_priority_list",
                "mutect,varscan,strelka,pindel,docm",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/combined.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:docm",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/docm_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:mutect",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/mutect_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:pindel",
                        "position": 5
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/pindel_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#combine_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:strelka",
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/strelka_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:varscan",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_variants.cwl/varscan_vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "combined.vcf.gz"
                    },
                    "id": "#combine_variants.cwl/combined_vcf"
                }
            ],
            "id": "#combine_variants.cwl"
        },
        {
            "class": "Workflow",
            "label": "Detect Variants workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/coding_only"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/cosmic_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/docm_vcf"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/hgvs_annotation"
                },
                {
                    "type": "File",
                    "id": "#main/interval_list"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/mutect_artifact_detection_mode"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#main/mutect_max_alt_allele_in_normal_fraction"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/mutect_max_alt_alleles_in_normal_count"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/mutect_scatter_count"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai",
                        ".crai"
                    ],
                    "id": "#main/normal_cram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/panel_of_normals_vcf"
                },
                {
                    "type": "int",
                    "default": 400,
                    "id": "#main/pindel_insert_size"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "boolean",
                    "id": "#main/strelka_exome_mode"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/synonyms_file"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai",
                        ".crai"
                    ],
                    "id": "#main/tumor_cram"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "CHROM",
                        "POS",
                        "ID",
                        "REF",
                        "ALT",
                        "set",
                        "AC",
                        "AF"
                    ],
                    "id": "#main/variants_to_table_fields"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "GT",
                        "AD"
                    ],
                    "id": "#main/variants_to_table_genotype_fields"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#main/varscan_max_normal_freq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#main/varscan_min_coverage"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "id": "#main/varscan_min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "id": "#main/varscan_p_value"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#main/varscan_strand_filter"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/vep_cache_dir"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "HGVSc",
                        "HGVSp"
                    ],
                    "id": "#main/vep_to_table_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/docm/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/docm_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/docm/unfiltered_vcf",
                    "id": "#main/docm_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/add_vep_fields_to_table/annotated_variants_tsv",
                    "id": "#main/final_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/final_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/mutect/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/mutect_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/mutect/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/mutect_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/normal_bam_readcount/indel_bam_readcount",
                    "id": "#main/normal_indel_bam_readcount"
                },
                {
                    "type": "File",
                    "outputSource": "#main/normal_bam_readcount/snv_bam_readcount",
                    "id": "#main/normal_snv_bam_readcount"
                },
                {
                    "type": "File",
                    "outputSource": "#main/pindel/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/pindel_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/pindel/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/pindel_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/strelka/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/strelka_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/strelka/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/strelka_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/tumor_bam_readcount/indel_bam_readcount",
                    "id": "#main/tumor_indel_bam_readcount"
                },
                {
                    "type": "File",
                    "outputSource": "#main/tumor_bam_readcount/snv_bam_readcount",
                    "id": "#main/tumor_snv_bam_readcount"
                },
                {
                    "type": "File",
                    "outputSource": "#main/varscan/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/varscan_filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/varscan/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/varscan_unfiltered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/annotate_variants/vep_summary",
                    "id": "#main/vep_summary"
                }
            ],
            "steps": [
                {
                    "run": "#add_vep_fields_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/variants_to_table/variants_tsv",
                            "id": "#main/add_vep_fields_to_table/tsv"
                        },
                        {
                            "source": "#main/index/indexed_vcf",
                            "id": "#main/add_vep_fields_to_table/vcf"
                        },
                        {
                            "source": "#main/vep_to_table_fields",
                            "id": "#main/add_vep_fields_to_table/vep_fields"
                        }
                    ],
                    "out": [
                        "#main/add_vep_fields_to_table/annotated_variants_tsv"
                    ],
                    "id": "#main/add_vep_fields_to_table"
                },
                {
                    "run": "#vep.cwl",
                    "in": [
                        {
                            "source": "#main/vep_cache_dir",
                            "id": "#main/annotate_variants/cache_dir"
                        },
                        {
                            "source": "#main/coding_only",
                            "id": "#main/annotate_variants/coding_only"
                        },
                        {
                            "source": "#main/hgvs_annotation",
                            "id": "#main/annotate_variants/hgvs"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/annotate_variants/reference"
                        },
                        {
                            "source": "#main/synonyms_file",
                            "id": "#main/annotate_variants/synonyms_file"
                        },
                        {
                            "source": "#main/combine/combined_vcf",
                            "id": "#main/annotate_variants/vcf"
                        }
                    ],
                    "out": [
                        "#main/annotate_variants/annotated_vcf",
                        "#main/annotate_variants/vep_summary"
                    ],
                    "id": "#main/annotate_variants"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#main/annotate_variants/annotated_vcf",
                            "id": "#main/bgzip/file"
                        }
                    ],
                    "out": [
                        "#main/bgzip/bgzipped_file"
                    ],
                    "id": "#main/bgzip"
                },
                {
                    "run": "#combine_variants.cwl",
                    "in": [
                        {
                            "source": "#main/docm/filtered_vcf",
                            "id": "#main/combine/docm_vcf"
                        },
                        {
                            "source": "#main/mutect/filtered_vcf",
                            "id": "#main/combine/mutect_vcf"
                        },
                        {
                            "source": "#main/pindel/filtered_vcf",
                            "id": "#main/combine/pindel_vcf"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/combine/reference"
                        },
                        {
                            "source": "#main/strelka/filtered_vcf",
                            "id": "#main/combine/strelka_vcf"
                        },
                        {
                            "source": "#main/varscan/filtered_vcf",
                            "id": "#main/combine/varscan_vcf"
                        }
                    ],
                    "out": [
                        "#main/combine/combined_vcf"
                    ],
                    "id": "#main/combine"
                },
                {
                    "run": "#workflow.cwl_2",
                    "in": [
                        {
                            "source": "#main/docm_vcf",
                            "id": "#main/docm/docm_vcf"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/docm/interval_list"
                        },
                        {
                            "source": "#main/normal_cram",
                            "id": "#main/docm/normal_cram"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/docm/reference"
                        },
                        {
                            "source": "#main/tumor_cram",
                            "id": "#main/docm/tumor_cram"
                        }
                    ],
                    "out": [
                        "#main/docm/unfiltered_vcf",
                        "#main/docm/filtered_vcf"
                    ],
                    "id": "#main/docm"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#main/bgzip/bgzipped_file",
                            "id": "#main/index/vcf"
                        }
                    ],
                    "out": [
                        "#main/index/indexed_vcf"
                    ],
                    "id": "#main/index"
                },
                {
                    "run": "#workflow.cwl_4",
                    "in": [
                        {
                            "source": "#main/mutect_artifact_detection_mode",
                            "id": "#main/mutect/artifact_detection_mode"
                        },
                        {
                            "source": "#main/cosmic_vcf",
                            "id": "#main/mutect/cosmic_vcf"
                        },
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/mutect/dbsnp_vcf"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/mutect/interval_list"
                        },
                        {
                            "source": "#main/mutect_max_alt_allele_in_normal_fraction",
                            "id": "#main/mutect/max_alt_allele_in_normal_fraction"
                        },
                        {
                            "source": "#main/mutect_max_alt_alleles_in_normal_count",
                            "id": "#main/mutect/max_alt_alleles_in_normal_count"
                        },
                        {
                            "source": "#main/normal_cram",
                            "id": "#main/mutect/normal_cram"
                        },
                        {
                            "source": "#main/panel_of_normals_vcf",
                            "id": "#main/mutect/panel_of_normals_vcf"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/mutect/reference"
                        },
                        {
                            "source": "#main/mutect_scatter_count",
                            "id": "#main/mutect/scatter_count"
                        },
                        {
                            "source": "#main/tumor_cram",
                            "id": "#main/mutect/tumor_cram"
                        }
                    ],
                    "out": [
                        "#main/mutect/unfiltered_vcf",
                        "#main/mutect/filtered_vcf"
                    ],
                    "id": "#main/mutect"
                },
                {
                    "run": "#bam_readcount.cwl",
                    "in": [
                        {
                            "source": "#main/normal_cram_to_bam/bam",
                            "id": "#main/normal_bam_readcount/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/normal_bam_readcount/reference_fasta"
                        },
                        {
                            "default": "NORMAL",
                            "id": "#main/normal_bam_readcount/sample"
                        },
                        {
                            "source": "#main/combine/combined_vcf",
                            "id": "#main/normal_bam_readcount/vcf"
                        }
                    ],
                    "out": [
                        "#main/normal_bam_readcount/snv_bam_readcount",
                        "#main/normal_bam_readcount/indel_bam_readcount"
                    ],
                    "id": "#main/normal_bam_readcount"
                },
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#main/normal_cram",
                            "id": "#main/normal_cram_to_bam/cram"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/normal_cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#main/normal_cram_to_bam/bam"
                    ],
                    "id": "#main/normal_cram_to_bam"
                },
                {
                    "run": "#workflow.cwl_5",
                    "in": [
                        {
                            "source": "#main/pindel_insert_size",
                            "id": "#main/pindel/insert_size"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/pindel/interval_list"
                        },
                        {
                            "source": "#main/normal_cram",
                            "id": "#main/pindel/normal_cram"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/pindel/reference"
                        },
                        {
                            "source": "#main/tumor_cram",
                            "id": "#main/pindel/tumor_cram"
                        }
                    ],
                    "out": [
                        "#main/pindel/unfiltered_vcf",
                        "#main/pindel/filtered_vcf"
                    ],
                    "id": "#main/pindel"
                },
                {
                    "run": "#workflow.cwl_6",
                    "in": [
                        {
                            "source": "#main/strelka_exome_mode",
                            "id": "#main/strelka/exome_mode"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/strelka/interval_list"
                        },
                        {
                            "source": "#main/normal_cram",
                            "id": "#main/strelka/normal_cram"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/strelka/reference"
                        },
                        {
                            "source": "#main/tumor_cram",
                            "id": "#main/strelka/tumor_cram"
                        }
                    ],
                    "out": [
                        "#main/strelka/unfiltered_vcf",
                        "#main/strelka/filtered_vcf"
                    ],
                    "id": "#main/strelka"
                },
                {
                    "run": "#bam_readcount.cwl",
                    "in": [
                        {
                            "source": "#main/tumor_cram_to_bam/bam",
                            "id": "#main/tumor_bam_readcount/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/tumor_bam_readcount/reference_fasta"
                        },
                        {
                            "default": "TUMOR",
                            "id": "#main/tumor_bam_readcount/sample"
                        },
                        {
                            "source": "#main/combine/combined_vcf",
                            "id": "#main/tumor_bam_readcount/vcf"
                        }
                    ],
                    "out": [
                        "#main/tumor_bam_readcount/snv_bam_readcount",
                        "#main/tumor_bam_readcount/indel_bam_readcount"
                    ],
                    "id": "#main/tumor_bam_readcount"
                },
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#main/tumor_cram",
                            "id": "#main/tumor_cram_to_bam/cram"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/tumor_cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#main/tumor_cram_to_bam/bam"
                    ],
                    "id": "#main/tumor_cram_to_bam"
                },
                {
                    "run": "#variants_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/variants_to_table_fields",
                            "id": "#main/variants_to_table/fields"
                        },
                        {
                            "source": "#main/variants_to_table_genotype_fields",
                            "id": "#main/variants_to_table/genotype_fields"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/variants_to_table/reference"
                        },
                        {
                            "source": "#main/index/indexed_vcf",
                            "id": "#main/variants_to_table/vcf"
                        }
                    ],
                    "out": [
                        "#main/variants_to_table/variants_tsv"
                    ],
                    "id": "#main/variants_to_table"
                },
                {
                    "run": "#workflow.cwl_7",
                    "in": [
                        {
                            "source": "#main/interval_list",
                            "id": "#main/varscan/interval_list"
                        },
                        {
                            "source": "#main/varscan_max_normal_freq",
                            "id": "#main/varscan/max_normal_freq"
                        },
                        {
                            "source": "#main/varscan_min_coverage",
                            "id": "#main/varscan/min_coverage"
                        },
                        {
                            "source": "#main/varscan_min_var_freq",
                            "id": "#main/varscan/min_var_freq"
                        },
                        {
                            "source": "#main/normal_cram",
                            "id": "#main/varscan/normal_cram"
                        },
                        {
                            "source": "#main/varscan_p_value",
                            "id": "#main/varscan/p_value"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/varscan/reference"
                        },
                        {
                            "source": "#main/varscan_strand_filter",
                            "id": "#main/varscan/strand_filter"
                        },
                        {
                            "source": "#main/tumor_cram",
                            "id": "#main/varscan/tumor_cram"
                        }
                    ],
                    "out": [
                        "#main/varscan/unfiltered_vcf",
                        "#main/varscan/filtered_vcf"
                    ],
                    "id": "#main/varscan"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index.cwl/indexed_vcf"
                }
            ],
            "id": "#index.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "cp",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf merge",
            "baseCommand": [
                "/opt/bcftools/bin/bcftools",
                "concat"
            ],
            "arguments": [
                "--allow-overlaps",
                "--remove-duplicates",
                "--output-type",
                "z",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.merged_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "merged",
                    "id": "#merge.cwl/merged_vcf_basename"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#merge.cwl/vcfs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.merged_vcf_basename).vcf.gz"
                    },
                    "id": "#merge.cwl/merged_vcf"
                }
            ],
            "id": "#merge.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--excludeFiltered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/split_interval_list_helper.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000
                }
            ],
            "arguments": [
                {
                    "valueFrom": "OUTPUT=$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "separate": false,
                        "position": 1
                    },
                    "id": "#split_interval_list.cwl/interval_list"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "SCATTER_COUNT=",
                        "separate": false,
                        "position": 2
                    },
                    "id": "#split_interval_list.cwl/scatter_count"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.interval_list"
                    },
                    "id": "#split_interval_list.cwl/split_interval_lists"
                }
            ],
            "id": "#split_interval_list.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "VariantsToTable"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/variants.tsv"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-F"
                        }
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#variants_to_table.cwl/fields"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GF"
                        }
                    },
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#variants_to_table.cwl/genotype_fields"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#variants_to_table.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#variants_to_table.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "variants.tsv"
                    },
                    "id": "#variants_to_table.cwl/variants_tsv"
                }
            ],
            "id": "#variants_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Ensembl Variant Effect Predictor",
            "baseCommand": [
                "/usr/bin/perl",
                "-I",
                "/opt/lib/perl/VEP/Plugins",
                "/usr/bin/variant_effect_predictor.pl"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 32000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "--format",
                "vcf",
                "--vcf",
                "--plugin",
                "Downstream",
                "--plugin",
                "Wildtype",
                "--symbol",
                "--term",
                "SO",
                "--flag_pick",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.vcf"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.cache_dir) {\n        return [\"--offline\", \"--cache\", \"--af_exac\", \"--dir\", inputs.cache_dir ]\n    }\n    else {\n        return \"--database\"\n    }\n}\n",
                        "position": 4
                    },
                    "id": "#vep.cwl/cache_dir"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--coding_only",
                        "position": 3
                    },
                    "default": false,
                    "id": "#vep.cwl/coding_only"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.hgvs) {\n        if (inputs.cache_dir) {\n            return [\"--hgvs\", \"--fasta\", inputs.reference]\n        }\n        else {\n            return [\"--hgvs\"]\n        }\n    }\n    else {\n        return []\n    }\n}\n",
                        "position": 5
                    },
                    "id": "#vep.cwl/hgvs"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#vep.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--synonyms",
                        "position": 2
                    },
                    "id": "#vep.cwl/synonyms_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#vep.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.vcf"
                    },
                    "id": "#vep.cwl/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.vcf_summary.html"
                    },
                    "id": "#vep.cwl/vep_summary"
                }
            ],
            "id": "#vep.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "HaplotypeCaller (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "HaplotypeCaller"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "arguments": [
                "-gt_mode",
                "GENOTYPE_GIVEN_ALLELES",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/docm_out.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--alleles",
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#GATK_haplotype_caller.cwl/docm_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 5
                    },
                    "id": "#GATK_haplotype_caller.cwl/interval_list"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#GATK_haplotype_caller.cwl/normal_cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#GATK_haplotype_caller.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 3
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#GATK_haplotype_caller.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "docm_out.vcf"
                    },
                    "id": "#GATK_haplotype_caller.cwl/docm_out"
                }
            ],
            "id": "#GATK_haplotype_caller.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "docm filter",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/docm_filter.pl",
                "$(inputs.docm_out.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#docm_filter.cwl/docm_out"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "docm_filter_out.vcf"
                    },
                    "id": "#docm_filter.cwl/docm_filter_out"
                }
            ],
            "id": "#docm_filter.cwl"
        },
        {
            "class": "Workflow",
            "label": "Detect Docm variants",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/docm_vcf"
                },
                {
                    "type": "File",
                    "id": "#workflow.cwl_2/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_2/normal_cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_2/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_2/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_2/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_2/GATK_haplotype_caller/docm_out",
                    "id": "#workflow.cwl_2/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#GATK_haplotype_caller.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/docm_vcf",
                            "id": "#workflow.cwl_2/GATK_haplotype_caller/docm_vcf"
                        },
                        {
                            "source": "#workflow.cwl_2/interval_list",
                            "id": "#workflow.cwl_2/GATK_haplotype_caller/interval_list"
                        },
                        {
                            "source": "#workflow.cwl_2/normal_cram",
                            "id": "#workflow.cwl_2/GATK_haplotype_caller/normal_cram"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/GATK_haplotype_caller/reference"
                        },
                        {
                            "source": "#workflow.cwl_2/tumor_cram",
                            "id": "#workflow.cwl_2/GATK_haplotype_caller/tumor_cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/GATK_haplotype_caller/docm_out"
                    ],
                    "id": "#workflow.cwl_2/GATK_haplotype_caller"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/docm_filter/docm_filter_out",
                            "id": "#workflow.cwl_2/bgzip/file"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/bgzip/bgzipped_file"
                    ],
                    "id": "#workflow.cwl_2/bgzip"
                },
                {
                    "run": "#docm_filter.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/GATK_haplotype_caller/docm_out",
                            "id": "#workflow.cwl_2/docm_filter/docm_out"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/docm_filter/docm_filter_out"
                    ],
                    "id": "#workflow.cwl_2/docm_filter"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/bgzip/bgzipped_file",
                            "id": "#workflow.cwl_2/index/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/index/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_2/index"
                }
            ],
            "id": "#workflow.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "False Positive filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/fpfilter.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "--sample",
                "TUMOR",
                "--bam-readcount",
                "/usr/bin/bam-readcount",
                "--samtools",
                "/opt/samtools/bin/samtools",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam-file",
                        "position": 2
                    },
                    "id": "#fp_filter.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "fpfilter",
                    "id": "#fp_filter.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--reference",
                        "position": 1
                    },
                    "id": "#fp_filter.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf-file",
                        "position": 3
                    },
                    "id": "#fp_filter.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf"
                    },
                    "id": "#fp_filter.cwl/filtered_vcf"
                }
            ],
            "id": "#fp_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Normalize variants",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "LeftAlignAndTrimVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "arguments": [
                "--splitMultiallelics",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/normalized.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#normalize_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#normalize_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "normalized.vcf.gz"
                    },
                    "id": "#normalize_variants.cwl/normalized_vcf"
                }
            ],
            "id": "#normalize_variants.cwl"
        },
        {
            "class": "Workflow",
            "label": "fp_filter workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_3/cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_3/reference"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_3/variant_caller"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_3/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_3/hard_filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_3/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_3/fp_index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_3/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/cram",
                            "id": "#workflow.cwl_3/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow.cwl_3/reference",
                            "id": "#workflow.cwl_3/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/cram_to_bam/bam"
                    ],
                    "id": "#workflow.cwl_3/cram_to_bam"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/fp_filter/filtered_vcf",
                            "id": "#workflow.cwl_3/fp_bgzip/file"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/fp_bgzip/bgzipped_file"
                    ],
                    "id": "#workflow.cwl_3/fp_bgzip"
                },
                {
                    "run": "#fp_filter.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/cram_to_bam/bam",
                            "id": "#workflow.cwl_3/fp_filter/bam"
                        },
                        {
                            "source": "#workflow.cwl_3/variant_caller",
                            "valueFrom": "$(self)_full",
                            "id": "#workflow.cwl_3/fp_filter/output_vcf_basename"
                        },
                        {
                            "source": "#workflow.cwl_3/reference",
                            "id": "#workflow.cwl_3/fp_filter/reference"
                        },
                        {
                            "source": "#workflow.cwl_3/normalize_variants/normalized_vcf",
                            "id": "#workflow.cwl_3/fp_filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/fp_filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_3/fp_filter"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/fp_bgzip/bgzipped_file",
                            "id": "#workflow.cwl_3/fp_index/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/fp_index/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_3/fp_index"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#workflow.cwl_3/hard_filter/exclude_filtered"
                        },
                        {
                            "source": "#workflow.cwl_3/variant_caller",
                            "valueFrom": "$(self)_filtered",
                            "id": "#workflow.cwl_3/hard_filter/output_vcf_basename"
                        },
                        {
                            "source": "#workflow.cwl_3/reference",
                            "id": "#workflow.cwl_3/hard_filter/reference"
                        },
                        {
                            "source": "#workflow.cwl_3/fp_index/indexed_vcf",
                            "id": "#workflow.cwl_3/hard_filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/hard_filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_3/hard_filter"
                },
                {
                    "run": "#normalize_variants.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_3/reference",
                            "id": "#workflow.cwl_3/normalize_variants/reference"
                        },
                        {
                            "source": "#workflow.cwl_3/vcf",
                            "id": "#workflow.cwl_3/normalize_variants/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_3/normalize_variants/normalized_vcf"
                    ],
                    "id": "#workflow.cwl_3/normalize_variants"
                }
            ],
            "id": "#workflow.cwl_3"
        },
        {
            "class": "CommandLineTool",
            "label": "mutect2 (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "MuTect2"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 20000,
                    "tmpdirMin": 100000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/mutect.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--artifact_detection_mode",
                        "position": 7
                    },
                    "id": "#mutect.cwl/artifact_detection_mode"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--cosmic",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl/cosmic_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--dbsnp",
                        "position": 5
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 4
                    },
                    "id": "#mutect.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--max_alt_allele_in_normal_fraction",
                        "position": 10
                    },
                    "id": "#mutect.cwl/max_alt_allele_in_normal_fraction"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max_alt_alleles_in_normal_count",
                        "position": 9
                    },
                    "id": "#mutect.cwl/max_alt_alleles_in_normal_count"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-I:normal",
                        "position": 3
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#mutect.cwl/normal_cram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-PON",
                        "position": 8
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl/panel_of_normals_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#mutect.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I:tumor",
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#mutect.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mutect.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl/vcf"
                }
            ],
            "id": "#mutect.cwl"
        },
        {
            "class": "Workflow",
            "label": "mutect parallel workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "id": "#workflow.cwl_4/artifact_detection_mode"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_4/cosmic_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_4/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "id": "#workflow.cwl_4/interval_list"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#workflow.cwl_4/max_alt_allele_in_normal_fraction"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#workflow.cwl_4/max_alt_alleles_in_normal_count"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_4/normal_cram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_4/panel_of_normals_vcf"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_4/reference"
                },
                {
                    "type": "int",
                    "id": "#workflow.cwl_4/scatter_count"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_4/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_4/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_4/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_4/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_4/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl_3",
                    "in": [
                        {
                            "source": "#workflow.cwl_4/tumor_cram",
                            "id": "#workflow.cwl_4/filter/cram"
                        },
                        {
                            "source": "#workflow.cwl_4/reference",
                            "id": "#workflow.cwl_4/filter/reference"
                        },
                        {
                            "valueFrom": "mutect",
                            "id": "#workflow.cwl_4/filter/variant_caller"
                        },
                        {
                            "source": "#workflow.cwl_4/index/indexed_vcf",
                            "id": "#workflow.cwl_4/filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_4/filter/unfiltered_vcf",
                        "#workflow.cwl_4/filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_4/filter"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_4/merge/merged_vcf",
                            "id": "#workflow.cwl_4/index/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_4/index/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_4/index"
                },
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_4/mutect/vcf",
                            "id": "#workflow.cwl_4/merge/vcfs"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_4/merge/merged_vcf"
                    ],
                    "id": "#workflow.cwl_4/merge"
                },
                {
                    "scatter": "#workflow.cwl_4/mutect/interval_list",
                    "run": "#mutect.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_4/artifact_detection_mode",
                            "id": "#workflow.cwl_4/mutect/artifact_detection_mode"
                        },
                        {
                            "source": "#workflow.cwl_4/cosmic_vcf",
                            "id": "#workflow.cwl_4/mutect/cosmic_vcf"
                        },
                        {
                            "source": "#workflow.cwl_4/dbsnp_vcf",
                            "id": "#workflow.cwl_4/mutect/dbsnp_vcf"
                        },
                        {
                            "source": "#workflow.cwl_4/split_interval_list/split_interval_lists",
                            "id": "#workflow.cwl_4/mutect/interval_list"
                        },
                        {
                            "source": "#workflow.cwl_4/max_alt_allele_in_normal_fraction",
                            "id": "#workflow.cwl_4/mutect/max_alt_allele_in_normal_fraction"
                        },
                        {
                            "source": "#workflow.cwl_4/max_alt_alleles_in_normal_count",
                            "id": "#workflow.cwl_4/mutect/max_alt_alleles_in_normal_count"
                        },
                        {
                            "source": "#workflow.cwl_4/normal_cram",
                            "id": "#workflow.cwl_4/mutect/normal_cram"
                        },
                        {
                            "source": "#workflow.cwl_4/panel_of_normals_vcf",
                            "id": "#workflow.cwl_4/mutect/panel_of_normals_vcf"
                        },
                        {
                            "source": "#workflow.cwl_4/reference",
                            "id": "#workflow.cwl_4/mutect/reference"
                        },
                        {
                            "source": "#workflow.cwl_4/tumor_cram",
                            "id": "#workflow.cwl_4/mutect/tumor_cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_4/mutect/vcf"
                    ],
                    "id": "#workflow.cwl_4/mutect"
                },
                {
                    "run": "#split_interval_list.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_4/interval_list",
                            "id": "#workflow.cwl_4/split_interval_list/interval_list"
                        },
                        {
                            "source": "#workflow.cwl_4/scatter_count",
                            "id": "#workflow.cwl_4/split_interval_list/scatter_count"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_4/split_interval_list/split_interval_lists"
                    ],
                    "id": "#workflow.cwl_4/split_interval_list"
                }
            ],
            "id": "#workflow.cwl_4"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/cat"
            ],
            "stdout": "all_chromosome_pindel.out",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cat_all.cwl/chromosome_pindel_outs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cat_all.cwl/all_chromosome_pindel_out",
                    "outputBinding": {
                        "glob": "all_chromosome_pindel.out"
                    }
                }
            ],
            "id": "#cat_all.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/cat"
            ],
            "stdout": "per_chromosome_pindel.out",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cat_out.cwl/pindel_outs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cat_out.cwl/pindel_out",
                    "outputBinding": {
                        "glob": "per_chromosome_pindel.out"
                    }
                }
            ],
            "id": "#cat_out.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "bash",
                "-c",
                "/bin/grep -v '^@' $1 | /usr/bin/cut -f 1 | /usr/bin/sort | /usr/bin/uniq",
                "--"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "chromosome.list",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#get_chromosome_list.cwl/interval_list"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "outputBinding": {
                        "glob": "chromosome.list",
                        "loadContents": true,
                        "outputEval": "$( self[0].contents.split(\"\\n\").slice(0, -1))"
                    },
                    "id": "#get_chromosome_list.cwl/chromosome_list"
                }
            ],
            "id": "#get_chromosome_list.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/grep",
                "ChrID"
            ],
            "stdout": "all_chromosome_pindel.head",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#grep.cwl/pindel_output"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#grep.cwl/pindel_head",
                    "outputBinding": {
                        "glob": "all_chromosome_pindel.head"
                    }
                }
            ],
            "id": "#grep.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "pindel v0.2.5b8",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/pindel_helper.pl",
                "$(inputs.normal_cram.path)",
                "$(inputs.tumor_cram.path)",
                "$(inputs.insert_size)"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "tmpdirMin": 100000
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-c",
                        "position": 2
                    },
                    "id": "#pindel.cwl/chromosome"
                },
                {
                    "type": "int",
                    "default": 400,
                    "id": "#pindel.cwl/insert_size"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#pindel.cwl/normal_cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 1
                    },
                    "id": "#pindel.cwl/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#pindel.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_D"
                    },
                    "id": "#pindel.cwl/deletions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_SI"
                    },
                    "id": "#pindel.cwl/insertions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_INV"
                    },
                    "id": "#pindel.cwl/inversions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_LI"
                    },
                    "id": "#pindel.cwl/long_insertions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_TD"
                    },
                    "id": "#pindel.cwl/tandems"
                }
            ],
            "id": "#pindel.cwl"
        },
        {
            "class": "Workflow",
            "label": "Per-chromosome pindel",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#pindel_cat.cwl/chromosome"
                },
                {
                    "type": "int",
                    "default": 400,
                    "id": "#pindel_cat.cwl/insert_size"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#pindel_cat.cwl/normal_cram"
                },
                {
                    "type": "string",
                    "id": "#pindel_cat.cwl/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#pindel_cat.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#pindel_cat.cwl/cat/pindel_out",
                    "id": "#pindel_cat.cwl/per_chromosome_pindel_out"
                }
            ],
            "steps": [
                {
                    "run": "#cat_out.cwl",
                    "in": [
                        {
                            "source": [
                                "#pindel_cat.cwl/pindel/deletions",
                                "#pindel_cat.cwl/pindel/insertions",
                                "#pindel_cat.cwl/pindel/tandems",
                                "#pindel_cat.cwl/pindel/long_insertions",
                                "#pindel_cat.cwl/pindel/inversions"
                            ],
                            "id": "#pindel_cat.cwl/cat/pindel_outs"
                        }
                    ],
                    "out": [
                        "#pindel_cat.cwl/cat/pindel_out"
                    ],
                    "id": "#pindel_cat.cwl/cat"
                },
                {
                    "run": "#pindel.cwl",
                    "in": [
                        {
                            "source": "#pindel_cat.cwl/chromosome",
                            "id": "#pindel_cat.cwl/pindel/chromosome"
                        },
                        {
                            "source": "#pindel_cat.cwl/insert_size",
                            "id": "#pindel_cat.cwl/pindel/insert_size"
                        },
                        {
                            "source": "#pindel_cat.cwl/normal_cram",
                            "id": "#pindel_cat.cwl/pindel/normal_cram"
                        },
                        {
                            "source": "#pindel_cat.cwl/reference",
                            "id": "#pindel_cat.cwl/pindel/reference"
                        },
                        {
                            "source": "#pindel_cat.cwl/tumor_cram",
                            "id": "#pindel_cat.cwl/pindel/tumor_cram"
                        }
                    ],
                    "out": [
                        "#pindel_cat.cwl/pindel/deletions",
                        "#pindel_cat.cwl/pindel/insertions",
                        "#pindel_cat.cwl/pindel/tandems",
                        "#pindel_cat.cwl/pindel/long_insertions",
                        "#pindel_cat.cwl/pindel/inversions"
                    ],
                    "id": "#pindel_cat.cwl/pindel"
                }
            ],
            "id": "#pindel_cat.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "remove END INFO tags",
            "baseCommand": [
                "/opt/bcftools/bin/bcftools",
                "annotate"
            ],
            "arguments": [
                "-x",
                "INFO/END",
                "-Oz",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/pindel.noend.vcf.gz"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#remove_end_tags.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "pindel.noend.vcf.gz"
                    },
                    "id": "#remove_end_tags.cwl/processed_vcf"
                }
            ],
            "id": "#remove_end_tags.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "pindel somatic filter v1",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/write_pindel_filter_config.pl",
                "$(inputs.pindel_output_summary.path)",
                "$(inputs.reference)",
                "$(runtime.outdir)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/perl",
                "/usr/bin/somatic_indelfilter.pl",
                "filter.config"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#somaticfilter.cwl/pindel_output_summary"
                },
                {
                    "type": "string",
                    "id": "#somaticfilter.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "pindel.out.vcf"
                    },
                    "id": "#somaticfilter.cwl/vcf"
                }
            ],
            "id": "#somaticfilter.cwl"
        },
        {
            "class": "Workflow",
            "label": "pindel parallel workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "default": 400,
                    "id": "#workflow.cwl_5/insert_size"
                },
                {
                    "type": "File",
                    "id": "#workflow.cwl_5/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_5/normal_cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_5/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_5/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_5/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_5/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_5/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_5/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/somaticfilter/vcf",
                            "id": "#workflow.cwl_5/bgzip/file"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/bgzip/bgzipped_file"
                    ],
                    "id": "#workflow.cwl_5/bgzip"
                },
                {
                    "run": "#cat_all.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/pindel_cat/per_chromosome_pindel_out",
                            "id": "#workflow.cwl_5/cat_all/chromosome_pindel_outs"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/cat_all/all_chromosome_pindel_out"
                    ],
                    "id": "#workflow.cwl_5/cat_all"
                },
                {
                    "run": "#workflow.cwl_3",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/tumor_cram",
                            "id": "#workflow.cwl_5/filter/cram"
                        },
                        {
                            "source": "#workflow.cwl_5/reference",
                            "id": "#workflow.cwl_5/filter/reference"
                        },
                        {
                            "valueFrom": "pindel",
                            "id": "#workflow.cwl_5/filter/variant_caller"
                        },
                        {
                            "source": "#workflow.cwl_5/reindex/indexed_vcf",
                            "id": "#workflow.cwl_5/filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/filter/unfiltered_vcf",
                        "#workflow.cwl_5/filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_5/filter"
                },
                {
                    "run": "#get_chromosome_list.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/interval_list",
                            "id": "#workflow.cwl_5/get_chromosome_list/interval_list"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/get_chromosome_list/chromosome_list"
                    ],
                    "id": "#workflow.cwl_5/get_chromosome_list"
                },
                {
                    "run": "#grep.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/cat_all/all_chromosome_pindel_out",
                            "id": "#workflow.cwl_5/grep/pindel_output"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/grep/pindel_head"
                    ],
                    "id": "#workflow.cwl_5/grep"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/bgzip/bgzipped_file",
                            "id": "#workflow.cwl_5/index/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/index/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_5/index"
                },
                {
                    "scatter": "#workflow.cwl_5/pindel_cat/chromosome",
                    "run": "#pindel_cat.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/get_chromosome_list/chromosome_list",
                            "id": "#workflow.cwl_5/pindel_cat/chromosome"
                        },
                        {
                            "source": "#workflow.cwl_5/insert_size",
                            "id": "#workflow.cwl_5/pindel_cat/insert_size"
                        },
                        {
                            "source": "#workflow.cwl_5/normal_cram",
                            "id": "#workflow.cwl_5/pindel_cat/normal_cram"
                        },
                        {
                            "source": "#workflow.cwl_5/reference",
                            "id": "#workflow.cwl_5/pindel_cat/reference"
                        },
                        {
                            "source": "#workflow.cwl_5/tumor_cram",
                            "id": "#workflow.cwl_5/pindel_cat/tumor_cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/pindel_cat/per_chromosome_pindel_out"
                    ],
                    "id": "#workflow.cwl_5/pindel_cat"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/interval_list",
                            "id": "#workflow.cwl_5/region_filter/interval_list"
                        },
                        {
                            "source": "#workflow.cwl_5/reference",
                            "id": "#workflow.cwl_5/region_filter/reference"
                        },
                        {
                            "source": "#workflow.cwl_5/index/indexed_vcf",
                            "id": "#workflow.cwl_5/region_filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/region_filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_5/region_filter"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/remove_end_tags/processed_vcf",
                            "id": "#workflow.cwl_5/reindex/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/reindex/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_5/reindex"
                },
                {
                    "run": "#remove_end_tags.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/region_filter/filtered_vcf",
                            "id": "#workflow.cwl_5/remove_end_tags/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/remove_end_tags/processed_vcf"
                    ],
                    "id": "#workflow.cwl_5/remove_end_tags"
                },
                {
                    "run": "#somaticfilter.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_5/grep/pindel_head",
                            "id": "#workflow.cwl_5/somaticfilter/pindel_output_summary"
                        },
                        {
                            "source": "#workflow.cwl_5/reference",
                            "id": "#workflow.cwl_5/somaticfilter/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_5/somaticfilter/vcf"
                    ],
                    "id": "#workflow.cwl_5/somaticfilter"
                }
            ],
            "id": "#workflow.cwl_5"
        },
        {
            "class": "CommandLineTool",
            "label": "run bam-readcount",
            "baseCommand": [
                "/usr/bin/python",
                "/usr/bin/bam_readcount_helper.py"
            ],
            "arguments": [
                {
                    "position": 5,
                    "valueFrom": "$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bam_readcount.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bam_readcount.cwl/reference_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bam_readcount.cwl/sample"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bam_readcount.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.sample)_bam_readcount_indel.tsv"
                    },
                    "id": "#bam_readcount.cwl/indel_bam_readcount"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.sample)_bam_readcount_snv.tsv"
                    },
                    "id": "#bam_readcount.cwl/snv_bam_readcount"
                }
            ],
            "id": "#bam_readcount.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add GT tags",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/add_strelka_gt.pl",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#add_gt.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "add_gt.vcf"
                    },
                    "id": "#add_gt.cwl/processed_vcf"
                }
            ],
            "id": "#add_gt.cwl"
        },
        {
            "class": "Workflow",
            "label": "process VCF workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#process_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#process_vcf.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#process_vcf.cwl/processed_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#add_gt.cwl",
                    "in": [
                        {
                            "source": "#process_vcf.cwl/vcf",
                            "id": "#process_vcf.cwl/add_gt/vcf"
                        }
                    ],
                    "out": [
                        "#process_vcf.cwl/add_gt/processed_vcf"
                    ],
                    "id": "#process_vcf.cwl/add_gt"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#process_vcf.cwl/add_gt/processed_vcf",
                            "id": "#process_vcf.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#process_vcf.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#process_vcf.cwl/bgzip"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#process_vcf.cwl/bgzip/bgzipped_file",
                            "id": "#process_vcf.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#process_vcf.cwl/index/indexed_vcf"
                    ],
                    "id": "#process_vcf.cwl/index"
                }
            ],
            "id": "#process_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "strelka 2.7.1",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/strelka_helper.pl"
            ],
            "requirements": [
                {
                    "coresMin": 8,
                    "ramMin": 4000,
                    "class": "ResourceRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.cores)",
                    "position": 1
                },
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": 2
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--exome",
                        "position": 6
                    },
                    "id": "#strelka.cwl/exome_mode"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--normalBam=",
                        "separate": false,
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".crai"
                    ],
                    "id": "#strelka.cwl/normal_cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--referenceFasta=",
                        "separate": false,
                        "position": 5
                    },
                    "id": "#strelka.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--tumorBam=",
                        "separate": false,
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".crai"
                    ],
                    "id": "#strelka.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/variants/somatic.indels.vcf.gz"
                    },
                    "id": "#strelka.cwl/indels"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "results/variants/somatic.snvs.vcf.gz"
                    },
                    "id": "#strelka.cwl/snvs"
                }
            ],
            "id": "#strelka.cwl"
        },
        {
            "class": "Workflow",
            "label": "strelka workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "id": "#workflow.cwl_6/exome_mode"
                },
                {
                    "type": "File",
                    "id": "#workflow.cwl_6/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai"
                    ],
                    "id": "#workflow.cwl_6/normal_cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_6/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai"
                    ],
                    "id": "#workflow.cwl_6/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_6/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_6/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_6/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_6/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl_3",
                    "in": [
                        {
                            "source": "#workflow.cwl_6/tumor_cram",
                            "id": "#workflow.cwl_6/filter/cram"
                        },
                        {
                            "source": "#workflow.cwl_6/reference",
                            "id": "#workflow.cwl_6/filter/reference"
                        },
                        {
                            "valueFrom": "strelka",
                            "id": "#workflow.cwl_6/filter/variant_caller"
                        },
                        {
                            "source": "#workflow.cwl_6/region_filter/filtered_vcf",
                            "id": "#workflow.cwl_6/filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_6/filter/unfiltered_vcf",
                        "#workflow.cwl_6/filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_6/filter"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_6/merge/merged_vcf",
                            "id": "#workflow.cwl_6/index_full/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_6/index_full/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_6/index_full"
                },
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_6/process/processed_vcf",
                            "id": "#workflow.cwl_6/merge/vcfs"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_6/merge/merged_vcf"
                    ],
                    "id": "#workflow.cwl_6/merge"
                },
                {
                    "scatter": "#workflow.cwl_6/process/vcf",
                    "run": "#process_vcf.cwl",
                    "in": [
                        {
                            "source": [
                                "#workflow.cwl_6/strelka/snvs",
                                "#workflow.cwl_6/strelka/indels"
                            ],
                            "id": "#workflow.cwl_6/process/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_6/process/processed_vcf"
                    ],
                    "id": "#workflow.cwl_6/process"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_6/interval_list",
                            "id": "#workflow.cwl_6/region_filter/interval_list"
                        },
                        {
                            "source": "#workflow.cwl_6/reference",
                            "id": "#workflow.cwl_6/region_filter/reference"
                        },
                        {
                            "source": "#workflow.cwl_6/index_full/indexed_vcf",
                            "id": "#workflow.cwl_6/region_filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_6/region_filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_6/region_filter"
                },
                {
                    "run": "#strelka.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_6/exome_mode",
                            "id": "#workflow.cwl_6/strelka/exome_mode"
                        },
                        {
                            "source": "#workflow.cwl_6/normal_cram",
                            "id": "#workflow.cwl_6/strelka/normal_cram"
                        },
                        {
                            "source": "#workflow.cwl_6/reference",
                            "id": "#workflow.cwl_6/strelka/reference"
                        },
                        {
                            "source": "#workflow.cwl_6/tumor_cram",
                            "id": "#workflow.cwl_6/strelka/tumor_cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_6/strelka/indels",
                        "#workflow.cwl_6/strelka/snvs"
                    ],
                    "id": "#workflow.cwl_6/strelka"
                }
            ],
            "id": "#workflow.cwl_6"
        },
        {
            "class": "Workflow",
            "label": "bgzip and index VCF",
            "inputs": [
                {
                    "type": "File",
                    "id": "#bgzip_and_index.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bgzip_and_index.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bgzip_and_index.cwl/indexed_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/vcf",
                            "id": "#bgzip_and_index.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#bgzip_and_index.cwl/bgzip"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/bgzip/bgzipped_file",
                            "id": "#bgzip_and_index.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/index/indexed_vcf"
                    ],
                    "id": "#bgzip_and_index.cwl/index"
                }
            ],
            "id": "#bgzip_and_index.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/intervals_to_bed.pl"
            ],
            "stdout": "interval_list.bed",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#intervals_to_bed.cwl/interval_list"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#intervals_to_bed.cwl/interval_bed",
                    "outputBinding": {
                        "glob": "interval_list.bed"
                    }
                }
            ],
            "id": "#intervals_to_bed.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "create filtered VCF",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "VariantFiltration"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "--maskName",
                "processSomatic",
                "--filterNotInMask",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/output.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--mask",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#set_filter_status.cwl/filtered_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#set_filter_status.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#set_filter_status.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.vcf.gz"
                    },
                    "id": "#set_filter_status.cwl/merged_vcf"
                }
            ],
            "id": "#set_filter_status.cwl"
        },
        {
            "class": "Workflow",
            "label": "varscan somatic workflow",
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#varscan.cwl/max_normal_freq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#varscan.cwl/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#varscan.cwl/min_var_freq"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#varscan.cwl/normal_cram"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#varscan.cwl/p_value"
                },
                {
                    "type": "string",
                    "id": "#varscan.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#varscan.cwl/roi_bed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#varscan.cwl/strand_filter"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#varscan.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/germline_hc",
                    "id": "#varscan.cwl/germline_hc_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/germline_hc",
                    "id": "#varscan.cwl/germline_hc_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/germline",
                    "id": "#varscan.cwl/germline_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/germline",
                    "id": "#varscan.cwl/germline_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/somatic/indels",
                    "id": "#varscan.cwl/indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/loh_hc",
                    "id": "#varscan.cwl/loh_hc_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/loh_hc",
                    "id": "#varscan.cwl/loh_hc_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/loh",
                    "id": "#varscan.cwl/loh_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/loh",
                    "id": "#varscan.cwl/loh_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/somatic/snvs",
                    "id": "#varscan.cwl/snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/somatic_hc",
                    "id": "#varscan.cwl/somatic_hc_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/somatic_hc",
                    "id": "#varscan.cwl/somatic_hc_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_indels/somatic",
                    "id": "#varscan.cwl/somatic_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan.cwl/process_somatic_snvs/somatic",
                    "id": "#varscan.cwl/somatic_snvs"
                }
            ],
            "steps": [
                {
                    "run": "#varscan_processsomatic.cwl",
                    "in": [
                        {
                            "source": "#varscan.cwl/max_normal_freq",
                            "id": "#varscan.cwl/process_somatic_indels/max_normal_freq"
                        },
                        {
                            "source": "#varscan.cwl/somatic/indels",
                            "id": "#varscan.cwl/process_somatic_indels/variants"
                        }
                    ],
                    "out": [
                        "#varscan.cwl/process_somatic_indels/somatic_hc",
                        "#varscan.cwl/process_somatic_indels/somatic",
                        "#varscan.cwl/process_somatic_indels/germline_hc",
                        "#varscan.cwl/process_somatic_indels/germline",
                        "#varscan.cwl/process_somatic_indels/loh_hc",
                        "#varscan.cwl/process_somatic_indels/loh"
                    ],
                    "id": "#varscan.cwl/process_somatic_indels"
                },
                {
                    "run": "#varscan_processsomatic.cwl",
                    "in": [
                        {
                            "source": "#varscan.cwl/max_normal_freq",
                            "id": "#varscan.cwl/process_somatic_snvs/max_normal_freq"
                        },
                        {
                            "source": "#varscan.cwl/somatic/snvs",
                            "id": "#varscan.cwl/process_somatic_snvs/variants"
                        }
                    ],
                    "out": [
                        "#varscan.cwl/process_somatic_snvs/somatic_hc",
                        "#varscan.cwl/process_somatic_snvs/somatic",
                        "#varscan.cwl/process_somatic_snvs/germline_hc",
                        "#varscan.cwl/process_somatic_snvs/germline",
                        "#varscan.cwl/process_somatic_snvs/loh_hc",
                        "#varscan.cwl/process_somatic_snvs/loh"
                    ],
                    "id": "#varscan.cwl/process_somatic_snvs"
                },
                {
                    "run": "#varscan_somatic.cwl",
                    "in": [
                        {
                            "source": "#varscan.cwl/min_coverage",
                            "id": "#varscan.cwl/somatic/min_coverage"
                        },
                        {
                            "source": "#varscan.cwl/min_var_freq",
                            "id": "#varscan.cwl/somatic/min_var_freq"
                        },
                        {
                            "source": "#varscan.cwl/normal_cram",
                            "id": "#varscan.cwl/somatic/normal_cram"
                        },
                        {
                            "source": "#varscan.cwl/p_value",
                            "id": "#varscan.cwl/somatic/p_value"
                        },
                        {
                            "source": "#varscan.cwl/reference",
                            "id": "#varscan.cwl/somatic/reference"
                        },
                        {
                            "source": "#varscan.cwl/roi_bed",
                            "id": "#varscan.cwl/somatic/roi_bed"
                        },
                        {
                            "source": "#varscan.cwl/strand_filter",
                            "id": "#varscan.cwl/somatic/strand_filter"
                        },
                        {
                            "source": "#varscan.cwl/tumor_cram",
                            "id": "#varscan.cwl/somatic/tumor_cram"
                        }
                    ],
                    "out": [
                        "#varscan.cwl/somatic/snvs",
                        "#varscan.cwl/somatic/indels"
                    ],
                    "id": "#varscan.cwl/somatic"
                }
            ],
            "id": "#varscan.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "varscan v2.4.2 processSomatic",
            "arguments": [
                "cp",
                "$(inputs.variants.path)",
                "$(runtime.outdir)/$(inputs.variants.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "java",
                "-jar",
                "/opt/varscan/VarScan.jar",
                "processSomatic"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--max-normal-freq",
                        "position": 2
                    },
                    "id": "#varscan_processsomatic.cwl/max_normal_freq"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(runtime.outdir)/$(self.basename)",
                        "position": 1
                    },
                    "id": "#varscan_processsomatic.cwl/variants"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Germline.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/germline"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Germline.hc.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/germline_hc"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.LOH.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/loh"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.LOH.hc.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/loh_hc"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Somatic.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/somatic"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Somatic.hc.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/somatic_hc"
                }
            ],
            "id": "#varscan_processsomatic.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "varscan v2.4.2 somatic",
            "baseCommand": "/usr/bin/varscan_helper.sh",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 12000
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#varscan_somatic.cwl/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "inputBinding": {
                        "position": 6
                    },
                    "id": "#varscan_somatic.cwl/min_var_freq"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#varscan_somatic.cwl/normal_cram"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#varscan_somatic.cwl/p_value"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#varscan_somatic.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#varscan_somatic.cwl/roi_bed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#varscan_somatic.cwl/strand_filter"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#varscan_somatic.cwl/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.indel.vcf"
                    },
                    "id": "#varscan_somatic.cwl/indels"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.snp.vcf"
                    },
                    "id": "#varscan_somatic.cwl/snvs"
                }
            ],
            "id": "#varscan_somatic.cwl"
        },
        {
            "class": "Workflow",
            "label": "Varscan Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#workflow.cwl_7/interval_list"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#workflow.cwl_7/max_normal_freq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#workflow.cwl_7/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "id": "#workflow.cwl_7/min_var_freq"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_7/normal_cram"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "id": "#workflow.cwl_7/p_value"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_7/reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#workflow.cwl_7/strand_filter"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_7/tumor_cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_7/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_7/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_7/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_7/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/varscan/somatic_hc_indels",
                            "id": "#workflow.cwl_7/bgzip_and_index_hc_indels/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/bgzip_and_index_hc_indels/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_7/bgzip_and_index_hc_indels"
                },
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/varscan/somatic_hc_snvs",
                            "id": "#workflow.cwl_7/bgzip_and_index_hc_snvs/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/bgzip_and_index_hc_snvs/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_7/bgzip_and_index_hc_snvs"
                },
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/varscan/somatic_indels",
                            "id": "#workflow.cwl_7/bgzip_and_index_indels/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/bgzip_and_index_indels/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_7/bgzip_and_index_indels"
                },
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/varscan/somatic_snvs",
                            "id": "#workflow.cwl_7/bgzip_and_index_snvs/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/bgzip_and_index_snvs/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_7/bgzip_and_index_snvs"
                },
                {
                    "run": "#workflow.cwl_3",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/tumor_cram",
                            "id": "#workflow.cwl_7/filter/cram"
                        },
                        {
                            "source": "#workflow.cwl_7/reference",
                            "id": "#workflow.cwl_7/filter/reference"
                        },
                        {
                            "valueFrom": "varscan",
                            "id": "#workflow.cwl_7/filter/variant_caller"
                        },
                        {
                            "source": "#workflow.cwl_7/index/indexed_vcf",
                            "id": "#workflow.cwl_7/filter/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/filter/unfiltered_vcf",
                        "#workflow.cwl_7/filter/filtered_vcf"
                    ],
                    "id": "#workflow.cwl_7/filter"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/merge/merged_vcf",
                            "id": "#workflow.cwl_7/index/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/index/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_7/index"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/merge_indels/merged_vcf",
                            "id": "#workflow.cwl_7/index_indels/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/index_indels/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_7/index_indels"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/merge_snvs/merged_vcf",
                            "id": "#workflow.cwl_7/index_snvs/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/index_snvs/indexed_vcf"
                    ],
                    "id": "#workflow.cwl_7/index_snvs"
                },
                {
                    "run": "#intervals_to_bed.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/interval_list",
                            "id": "#workflow.cwl_7/intervals_to_bed/interval_list"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/intervals_to_bed/interval_bed"
                    ],
                    "id": "#workflow.cwl_7/intervals_to_bed"
                },
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": [
                                "#workflow.cwl_7/index_snvs/indexed_vcf",
                                "#workflow.cwl_7/index_indels/indexed_vcf"
                            ],
                            "id": "#workflow.cwl_7/merge/vcfs"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/merge/merged_vcf"
                    ],
                    "id": "#workflow.cwl_7/merge"
                },
                {
                    "run": "#set_filter_status.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/bgzip_and_index_hc_indels/indexed_vcf",
                            "id": "#workflow.cwl_7/merge_indels/filtered_vcf"
                        },
                        {
                            "source": "#workflow.cwl_7/reference",
                            "id": "#workflow.cwl_7/merge_indels/reference"
                        },
                        {
                            "source": "#workflow.cwl_7/bgzip_and_index_indels/indexed_vcf",
                            "id": "#workflow.cwl_7/merge_indels/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/merge_indels/merged_vcf"
                    ],
                    "id": "#workflow.cwl_7/merge_indels"
                },
                {
                    "run": "#set_filter_status.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/bgzip_and_index_hc_snvs/indexed_vcf",
                            "id": "#workflow.cwl_7/merge_snvs/filtered_vcf"
                        },
                        {
                            "source": "#workflow.cwl_7/reference",
                            "id": "#workflow.cwl_7/merge_snvs/reference"
                        },
                        {
                            "source": "#workflow.cwl_7/bgzip_and_index_snvs/indexed_vcf",
                            "id": "#workflow.cwl_7/merge_snvs/vcf"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/merge_snvs/merged_vcf"
                    ],
                    "id": "#workflow.cwl_7/merge_snvs"
                },
                {
                    "run": "#varscan.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_7/max_normal_freq",
                            "id": "#workflow.cwl_7/varscan/max_normal_freq"
                        },
                        {
                            "source": "#workflow.cwl_7/min_coverage",
                            "id": "#workflow.cwl_7/varscan/min_coverage"
                        },
                        {
                            "source": "#workflow.cwl_7/min_var_freq",
                            "id": "#workflow.cwl_7/varscan/min_var_freq"
                        },
                        {
                            "source": "#workflow.cwl_7/normal_cram",
                            "id": "#workflow.cwl_7/varscan/normal_cram"
                        },
                        {
                            "source": "#workflow.cwl_7/p_value",
                            "id": "#workflow.cwl_7/varscan/p_value"
                        },
                        {
                            "source": "#workflow.cwl_7/reference",
                            "id": "#workflow.cwl_7/varscan/reference"
                        },
                        {
                            "source": "#workflow.cwl_7/intervals_to_bed/interval_bed",
                            "id": "#workflow.cwl_7/varscan/roi_bed"
                        },
                        {
                            "source": "#workflow.cwl_7/strand_filter",
                            "id": "#workflow.cwl_7/varscan/strand_filter"
                        },
                        {
                            "source": "#workflow.cwl_7/tumor_cram",
                            "id": "#workflow.cwl_7/varscan/tumor_cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_7/varscan/somatic_snvs",
                        "#workflow.cwl_7/varscan/somatic_indels",
                        "#workflow.cwl_7/varscan/somatic_hc_snvs",
                        "#workflow.cwl_7/varscan/somatic_hc_indels"
                    ],
                    "id": "#workflow.cwl_7/varscan"
                }
            ],
            "id": "#workflow.cwl_7"
        }
    ],
    "cwlVersion": "v1.0"
}
